-- Update table DBConfig : change the version of the DB to 2

UPDATE `DBConfig`
SET `version` = 2
WHERE `version` = 1;

-- Create table SeedBatchAlarms

CREATE TABLE `SeedBatchAlarms` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `germinationAlarmActivated` bit(1) NOT NULL,
  `germinationAlarmInDays` int(11) DEFAULT NULL,
  `harvestAlarmActivated` bit(1) NOT NULL,
  `harvestAlarmInDays` int(11) DEFAULT NULL,
  `storageAlarmActivated` bit(1) NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

-- Update Specie table to link it with SeedBatchAlarms table : add a foreign key
ALTER TABLE `Specie`
ADD COLUMN `seedBatchAlarms_id` int(11) NOT NULL;

-- create seed batch alarms for existing species : for that create a stored procedure
DELIMITER $$
 
CREATE PROCEDURE createSeedBatchAlarms()
BEGIN
	DECLARE finished INT DEFAULT 0;
	DECLARE seed_batch_alarms_id INT;
	DECLARE specie_id INT;
	
	
	-- declare cursor for specie id
	DEClARE specie_id_cursor CURSOR FOR SELECT id FROM `Specie` ORDER BY id;
 
	-- declare NOT FOUND handler
 	DECLARE CONTINUE HANDLER FOR NOT FOUND SET finished = 1;
 
 	OPEN specie_id_cursor;
 
 	-- loop on specie ids
	create_seed_batch_alarms: LOOP
 		FETCH specie_id_cursor INTO specie_id;
		IF finished = 1 THEN 
 			LEAVE create_seed_batch_alarms;
 		END IF;
 
 		-- create a new SeedBatchAlarms
 		INSERT INTO `SeedBatchAlarms` (`germinationAlarmActivated`, `germinationAlarmInDays`, `harvestAlarmActivated`, `harvestAlarmInDays`, `storageAlarmActivated`) 
 			VALUES (0, NULL, 0, NULL, 0);
 		SELECT LAST_INSERT_ID() INTO seed_batch_alarms_id;
 		
 		-- update the Specie table
 		UPDATE `Specie` SET `seedBatchAlarms_id`=seed_batch_alarms_id WHERE `id`=specie_id;

 	END LOOP create_seed_batch_alarms;

	CLOSE specie_id_cursor;

	
END$$
 
DELIMITER ;

CALL createSeedBatchAlarms();

-- update Specie table to link it with SeedBatchAlarms table : add the foreign key constraint

ALTER TABLE `Specie`
ADD CONSTRAINT SPECIE_SEED_BATCH_ALARMS_ID_FK FOREIGN KEY (`seedBatchAlarms_id`) REFERENCES `SeedBatchAlarms` (`id`);


-- Update Crossing table to add comment column
ALTER TABLE `Crossing`
ADD COLUMN `comment` varchar(255) DEFAULT NULL;

-- Update Mutagenesis table to add comment column
ALTER TABLE `Mutagenesis`
ADD COLUMN `comment` varchar(255) DEFAULT NULL;